Struct LatestLeapSeconds
pub struct LatestLeapSeconds { /* private fields */ }Expand description
List of leap seconds from https://data.iana.org/time-zones/data/leap-seconds.list. This list corresponds the number of seconds in TAI to the UTC offset and to whether it was an announced leap second or not. The unannoucned leap seconds come from dat.c in the SOFA library.
Implementations
impl LatestLeapSeconds
impl LatestLeapSeconds
pub fn __new__() -> LatestLeapSeconds ⓘ
impl LatestLeapSeconds
impl LatestLeapSeconds
pub fn is_up_to_date(&self) -> Result<bool, HifitimeError>
pub fn is_up_to_date(&self) -> Result<bool, HifitimeError>
Downloads the latest leap second list from IANA, and returns whether the embedded leap seconds are still up to date
use hifitime::leap_seconds::LatestLeapSeconds;
assert!(LatestLeapSeconds::default().is_up_to_date().unwrap(), "Hifitime needs to update its leap seconds list!");:rtype: bool