Struct LeapSecondsFile
pub struct LeapSecondsFile {
pub data: Vec<LeapSecond>,
/* private fields */
}Expand description
A leap second provider that uses an IERS formatted leap seconds file.
:type path: str
Fields
data: Vec<LeapSecond>Implementations
impl LeapSecondsFile
impl LeapSecondsFile
pub fn from_path<P>(path: P) -> Result<LeapSecondsFile, HifitimeError>
pub fn from_path<P>(path: P) -> Result<LeapSecondsFile, HifitimeError>
Builds a leap second provider from the provided Leap Seconds file in IERS format as found on https://data.iana.org/time-zones/data/leap-seconds.list .
pub fn from_content(contents: String) -> Result<LeapSecondsFile, HifitimeError>
pub fn from_content(contents: String) -> Result<LeapSecondsFile, HifitimeError>
Builds the leap seconds from the provided leap second list as string.
pub fn from_url(url: &str) -> Result<LeapSecondsFile, HifitimeError>
pub fn from_url(url: &str) -> Result<LeapSecondsFile, HifitimeError>
Build the leap seconds structure from the provided URL
pub fn from_iana() -> Result<LeapSecondsFile, HifitimeError>
pub fn from_iana() -> Result<LeapSecondsFile, HifitimeError>
Build the leap seconds structure from the latest leap seconds list from https://data.iana.org/time-zones/data/leap-seconds.list
impl LeapSecondsFile
impl LeapSecondsFile
pub fn __new__(path: String) -> Result<LeapSecondsFile, HifitimeError>